@@ -3,24 +3,23 @@
  *
  * This file is part of GNU GLOBAL.
  *
- * GNU GLOBAL is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- *
- * GNU GLOBAL is distributed in the hope that it will be useful,
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #ifndef _STRHASH_H
 #define _STRHASH_H
 
-#include "obstack.h"
+#include "pool.h"
 #include "queue.h"
 
 struct sh_entry {
@@ -34,7 +33,8 @@ SLIST_HEAD(sh_head, sh_entry);
 typedef struct {
 	int buckets;			/* number of buckets		*/
 	struct sh_head *htab;		/* hash buckets			*/
-	struct obstack pool;		/* memory pool for obstack	*/
+	POOL *pool;			/* memory pool			*/
+	unsigned long entries;		/* number of entries		*/
 	/*
 	 * iterator
 	 */
